@@ -196,7 +196,7 @@ class TalosProducer(object):
                     # set timestamp and messageType if not set
                     Utils.update_message(message, MessageType.BINARY)
                     # check data validity
-                    Utils.check_message_validity(message)
+                    Utils.check_message_validity(message, self.talosProducerConfig)
                     userMessageList.append(UserMessage(message))
 
                 assert partitionId in self.partitionSenderMap
@@ -227,7 +227,7 @@ class TalosProducer(object):
                 # set timestamp and messageType if not set;
                 Utils.update_message(message, MessageType.BINARY)
                 # check data validity
-                Utils.check_message_validity(message)
+                Utils.check_message_validity(message, self.talosProducerConfig)
 
                 # check partitionKey setting and validity
                 if not message.partitionKey:
